summaryrefslogtreecommitdiff
path: root/t/tap-basic.sh
diff options
context:
space:
mode:
Diffstat (limited to 't/tap-basic.sh')
-rw-r--r--t/tap-basic.sh15
1 files changed, 11 insertions, 4 deletions
diff --git a/t/tap-basic.sh b/t/tap-basic.sh
index 4aa859742..155d4b079 100644
--- a/t/tap-basic.sh
+++ b/t/tap-basic.sh
@@ -18,7 +18,7 @@
# - LOG_COMPILER support;
# - basic support for TODO and SKIP directives, and "Bail out!" magic;
# - testsuite progress output on console;
-# - runtime overriding of TESTS and TEST_LOGS;
+# - runtime overriding of TESTS;
# - correct counts of test results (both in summary and in progress
# output on console).
# Note that some of the features checked here are checked in other
@@ -44,7 +44,7 @@ ok.test:
echo 'ok 1' >> $@-t
echo 'not ok 2 # TODO' >>$@-t
echo 'ok 3 # SKIP' >>$@-t
- cat $@-t ;: For debugging.
+ cat $@-t # For debugging.
mv -f $@-t $@
END
@@ -72,6 +72,13 @@ ok 19 - nineteen # SKIP
ok 20 twenty twenty # SKIP
END
+cat > test-driver <<'END'
+#!/bin/sh
+echo "$0: required by Automake, but should never be actually used" >&2
+exit 1
+END
+chmod a+x test-driver
+
$ACLOCAL
$AUTOCONF
$AUTOMAKE
@@ -137,12 +144,12 @@ grep '^PASS:' stdout && exit 1
test $($FGREP -c ': bail.test' stdout) -eq 1
$FGREP 'success.test' stdout && exit 1
# Override TEST_LOGS from the command line, making it point to a test
# (ok.test) that has to be generated at make time.
rm -f *.log *.test
-run_make -O check TEST_LOGS=ok.log
+run_make -O check TESTS=ok
count_test_results total=3 pass=1 fail=0 xpass=0 xfail=1 skip=1 error=0
test -f ok.test
@@ -137,12 +144,12 @@ grep '^PASS:' stdout && exit 1
test $($FGREP -c ': bail.test' stdout) -eq 1
$FGREP 'success.test' stdout && exit 1
-# Override TEST_LOGS from the command line, making it point to a test
+# Override TESTS from the command line, making it point to a test
# (ok.test) that has to be generated at make time.
rm -f *.log *.test